@@ -1,6 +1,6 @@
 package File::CRBackup;
 BEGIN {
-  $File::CRBackup::VERSION = '0.04';
+  $File::CRBackup::VERSION = '0.05';
 }
 # ABSTRACT: Backup files/directories with histories, using cp+rsync
 
@@ -309,7 +309,7 @@ File::CRBackup - Backup files/directories with histories, using cp+rsync
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -532,9 +532,9 @@ L<File::Backup>
 
 L<File::Rotate::Backup>
 
-L<Snapback2>, which is a backup system using the same principle as outlined
-above, created in as early as 2004 (or earlier) by Mike Heins. Do check it out.
-I wish I had found it first before reinventing it in 2006 :-)
+L<Snapback2>, which is a backup system using the same basic principle (cp -la +
+rsync snapshots), created in as early as 2004 (or earlier) by Mike Heins. Do
+check it out. I wish I had found it first before reinventing it in 2006 :-)
 
 =head1 AUTHOR
 
